==> plugs-core_0.1.7.tar.gz: plugs-core-0.1.7/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from plugs_core/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("plugs_core", "__init__.py")


if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='plugs-core',
    version=version,
    description="""Your project description goes here""",
    long_description=readme + '\n\n' + history,
    author='Solo',
    author_email='geral@solo.com.pt',
    url='https://github.com/ricardolobo/plugs-core',
    packages=[
        'plugs_core',
    ],
    include_package_data=True,
    install_requires=[
        'django>=1.9.7',
        'djangorestframework==3.3.3',
        'djangorestframework-jwt>=1.8.0',
        'requests>=2.2.1',
        'PyJWT>=1.4.0,<2.0.0',
        'factory-boy>=2.7.0',
        'lxml'
    ],
    license="MIT",
    zip_safe=False,
    keywords='plugs-core',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.9',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content'
    ],
)

==> plugs-core-0.2.0.tar.gz: plugs-core-0.2.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from plugs_core/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("plugs_core", "__init__.py")


if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='plugs-core',
    version=version,
    description="""Reusable Core APP""",
    long_description=readme + '\n\n' + history,
    author='Solo',
    author_email='geral@solo.com.pt',
    url='https://github.com/solocompt/plugs-core',
    packages=[
        'plugs_core',
    ],
    include_package_data=True,
    install_requires=[
        'django>=1.11.4,<2.0.0',
        'djangorestframework>=3.6.4,<4.0.0',
        'djangorestframework-jwt>=1.8.0,<2.0.0',
        'requests>=2.2.1',
        'PyJWT>=1.4.0,<2.0.0',
        'factory-boy>=2.7.0',
        'lxml'
    ],
    license="MIT",
    zip_safe=False,
    keywords='plugs-core',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django :: 1.11',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3'
    ],
)
